<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

add_filter('lastudio-kit/branding/name', 'akali_lakit_branding_name');
if(!function_exists('akali_lakit_branding_name')){
    function akali_lakit_branding_name( $name ){
        $name = esc_html__('Theme Options', 'akali');
        return $name;
    }
}

add_filter('lastudio-kit/branding/logo', 'akali_lakit_branding_logo');
if(!function_exists('akali_lakit_branding_logo')){
    function akali_lakit_branding_logo( $logo ){
        $logo = '';
        return $logo;
    }
}

add_filter('lastudio-kit/logo/attr/src', 'akali_lakit_logo_attr_src');
if(!function_exists('akali_lakit_logo_attr_src')){
    function akali_lakit_logo_attr_src( $src ){
        if(!$src){
	        $src = akali_get_theme_mod('logo_default', get_theme_file_uri('/assets/images/logo.svg'));
        }
        return $src;
    }
}

add_filter('lastudio-kit/logo/attr/src2x', 'akali_lakit_logo_attr_src2x');
if(!function_exists('akali_lakit_logo_attr_src2x')){
    function akali_lakit_logo_attr_src2x( $src ){
        if(!$src){
	        $src = akali_get_theme_mod('logo_transparency', '');
        }
        return $src;
    }
}

add_filter('lastudio-kit/logo/attr/width', 'akali_lakit_logo_attr_width');
if(!function_exists('akali_lakit_logo_attr_width')){
    function akali_lakit_logo_attr_width( $value ){
        if(!$value){
            $value = 130;
        }
        return $value;
    }
}

add_filter('lastudio-kit/logo/attr/height', 'akali_lakit_logo_attr_height');
if(!function_exists('akali_lakit_logo_attr_height')){
    function akali_lakit_logo_attr_height( $value ){
        if(!$value){
            $value = 42;
        }
        return $value;
    }
}

add_action('elementor/frontend/widget/before_render', 'akali_lakit_add_class_into_sidebar_widget');
if(!function_exists('akali_lakit_add_class_into_sidebar_widget')){
    function akali_lakit_add_class_into_sidebar_widget( $widget ){
        if('sidebar' == $widget->get_name()){
            $widget->add_render_attribute('_wrapper', 'class' , 'widget-area');
        }
    }
}

add_filter('lastudio-kit/products/control/grid_style', 'akali_lakit_add_product_grid_style');
if(!function_exists('akali_lakit_add_product_grid_style')){
    function akali_lakit_add_product_grid_style( $preset ){
        return $preset;
    }
}
add_filter('lastudio-kit/products/control/list_style', 'akali_lakit_add_product_list_style');
if(!function_exists('akali_lakit_add_product_list_style')){
    function akali_lakit_add_product_list_style( $preset ){
        return $preset;
    }
}

add_filter('lastudio-kit/products/box_selector', 'akali_lakit_product_change_box_selector');
if(!function_exists('akali_lakit_product_change_box_selector')){
    function akali_lakit_product_change_box_selector(){
        return '{{WRAPPER}} ul.products .product_item--inner';
    }
}

add_filter('lastudio-kit/posts/format-icon', 'akali_lakit_change_postformat_icon', 10, 2);
if(!function_exists('akali_lakit_change_postformat_icon')){
    function akali_lakit_change_postformat_icon( $icon, $type ){
        return $icon;
    }
}

/**
 * Modify Divider - Weight control
 */
add_action('elementor/element/lakit-portfolio/section_settings/before_section_end', function( $element ){
	$element->add_control(
		'enable_portfolio_lightbox',
		[
			'label'     => esc_html__( 'Enable Lightbox', 'akali' ),
			'type'      => \Elementor\Controls_Manager::SWITCHER,
			'label_on'  => esc_html__( 'Yes', 'akali' ),
			'label_off' => esc_html__( 'No', 'akali' ),
			'default'   => '',
			'return_value' => 'enable-pf-lightbox',
			'prefix_class' => '',
		]
	);
}, 10 );

if(!function_exists('akali_elementor_register_custom_widgets')){
	function akali_elementor_register_custom_widgets(){
		require_once get_theme_file_path('/framework/third/elementor/postformat-widget.php');
		\Elementor\Plugin::instance()->widgets_manager->register( new Akali_Elementor_PostFormat_Content_Widget() );
	}
}

add_action( 'elementor/widgets/register', 'akali_elementor_register_custom_widgets' );

if(!function_exists('akali_remove_unwanted_metaboxes')){
    function akali_remove_unwanted_metaboxes( $type, $context, $post ){
        remove_meta_box('slider_revolution_metabox', $type, $context);
    }
}

add_action( 'do_meta_boxes', 'akali_remove_unwanted_metaboxes', 10, 3 );

if(!function_exists('akali_elementor_modify_widget_args')){
    function akali_elementor_modify_widget_args( $default_args, $widget ){
        $new_args = [
            'after_widget'	=> '</div>',
            'before_title'	=> '<div class="widget-title"><span>',
            'after_title'	=> '</span></div>',
        ];
        $widget_cssclass = sprintf('widget widget_%1$s %1$s', $widget->get_widget_instance()->id_base);
        if( !empty($widget->get_widget_instance()->widget_cssclass) ){
            $widget_cssclass = 'widget ' . $widget->get_widget_instance()->widget_cssclass;
        }
        $new_args['before_widget'] = sprintf('<div class="%1$s lakit-wp--widget" data-id="%2$s">', $widget_cssclass, $widget->get_id());

        return array_merge($default_args, $new_args);
    }
}

add_filter('elementor/widgets/wordpress/widget_args', 'akali_elementor_modify_widget_args', 20, 2);

add_filter('lastudio-kit/products/loop/wishlist-button/class', function( $cssClass ){
    global $product;
    if(Akali_WooCommerce_Wishlist::is_product_in_wishlist($product->get_id())){
        $cssClass .= ' added';
    }
    return $cssClass;
});

add_filter('lastudio-kit/products/loop/compare-button/class', function( $cssClass ){
    global $product;
    if(Akali_WooCommerce_Compare::is_product_in_compare($product->get_id())){
        $cssClass .= ' added';
    }
    return $cssClass;
});

add_filter('lastudio-kit/wishlist/settings', function ( $settings, $product, $product_id ){
    if(Akali_WooCommerce_Wishlist::is_product_in_wishlist($product_id)){
        $settings['link'] = [
            'url' => akali_get_wishlist_url(),
            'is_external' => '',
            'nofollow' => true,
            'custom_attributes' => 'class|added'
        ];
        $settings['text'] = esc_html_x('View Wishlist', 'front-view', 'akali');
    }
    else{
        $settings['link'] = [
            'url' => get_permalink($product_id),
            'is_external' => '',
            'nofollow' => true,
        ];
    }
    return $settings;
}, 20, 3);

add_filter('lastudio-kit/compare/settings', function ( $settings, $product, $product_id ){
    if(Akali_WooCommerce_Compare::is_product_in_compare($product_id)){
        $settings['link'] = [
            'url' => akali_get_compare_url(),
            'is_external' => '',
            'nofollow' => true,
            'custom_attributes' => 'class|added'
        ];
        $settings['text'] = esc_html_x('Compare List', 'front-view', 'akali');
    }
    else{
        $settings['link'] = [
            'url' => get_permalink($product_id),
            'is_external' => '',
            'nofollow' => true,
        ];
    }
    return $settings;
}, 20, 3);

add_action('lastudio-kit/posts/postformat-content', function ( $thumbnail_size ){
    $format_content = akali_get_post_thumbnail_format( $thumbnail_size, false, false );
    if($format_content !== '' && in_array(get_post_format(), ['gallery', 'quote'])){
        echo akali_render_variable($format_content);
    }
    else{
        ?>
        <a href="<?php the_permalink(); ?>" class="lakit-posts__thumbnail-link" aria-label="<?php the_title_attribute(['before' => esc_html__('Read more about', 'akali') . ' "', 'after' => '"']) ?>"><?php
            the_post_thumbnail($thumbnail_size, array(
                'class' => 'lakit-posts__thumbnail-img wp-post-image la-lazyload-image'
            ))
        ?></a>
        <?php
    }
}, 99);

add_filter('lastudio-kit/lakit-events/metadata/output', function ( $output, $key, $post_id ){
    if( !empty($output) && ($key === 'start_date' || $key === 'end_date') ){
        $_date = get_post_meta( $post_id, 'event_' . $key, true );
        $strtotime = strtotime($_date);
        $output = sprintf('<span class="m-d">%1$s</span> <span class="m-my"><span>%2$s</span><span class="cspr">,</span> <span>%3$s</span></span>', date('j', $strtotime), date('M', $strtotime), date('Y', $strtotime));
    }
    return $output;
}, 20, 3);

add_filter('lastudio-kit/lakit-woofilters/filter_type', function ( $type ){
    $type['nav_menu'] = esc_html_x('Nav Menu', 'admin-view','akali');
    return $type;
}, 20);

add_filter('lastudio-kit/posts/pagination_args', function ( $args ){
    $args['prev_text'] = is_rtl() ? '&rarr;' : '&larr;';
    $args['next_text'] = is_rtl() ? '&larr;' : '&rarr;';
    return $args;
});

add_filter('body_class', function ($classes){
	if( (isset($_GET['color_mode']) && $_GET['color_mode'] === 'dark') || (isset($_COOKIE['akali_color_mode']) && $_COOKIE['akali_color_mode'] === 'dark') ){
		$classes[] = 'body-dark';
	}
	return $classes;
}, 100);

add_action('template_redirect', function (){
	if( isset($_GET['color_mode']) ){
		@setcookie( 'akali_color_mode', $_GET['color_mode'] === 'dark' ? 'dark' : 'light', time() + DAY_IN_SECONDS, '/' );
	}
}, 100);